==> elasticsearch-ruby-8.19.1.tar.gz: elasticsearch-ruby-8.19.1/elasticsearch/spec/integration/opentelemetry_spec.rb <==
# Licensed to Elasticsearch B.V. under one or more contributor
# license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

if ENV['TEST_WITH_OTEL'] == 'true'
  ELASTICSEARCH_URL = ENV['TEST_ES_SERVER'] || "http://localhost:#{(ENV['PORT'] || 9200)}"
  raise URI::InvalidURIError unless ELASTICSEARCH_URL =~ /\A#{URI::DEFAULT_PARSER.make_regexp}\z/

  require 'spec_helper'

  context 'OpenTelemetry' do
    let(:exporter) { EXPORTER }
    before { exporter.reset }
    after { exporter.reset }
    let(:span) { exporter.finished_spans[0] }

    let(:client) do
      Elasticsearch::Client.new(
        host: ELASTICSEARCH_URL,
        user: 'elastic',
        password: 'changeme'
      )
    end

    after do
      client.delete(index: 'myindex', id: 1); rescue
    end

    context 'when a request is instrumented' do
      it 'sets the span name to the endpoint id' do
        client.search(body: { query: { match: { a: 1 } } })
        expect(span.name).to eq 'search'
      end

      it 'sets the path parts' do
        client.index(index: 'myindex', id: 1, body: { title: 'Test' })
        expect(span.attributes['db.elasticsearch.path_parts.index']).to eq 'myindex'
        expect(span.attributes['db.elasticsearch.path_parts.id']).to eq 1
      end
    end
  end
end

==> elasticsearch-ruby-9.2.0.tar.gz: elasticsearch-ruby-9.2.0/elasticsearch/spec/integration/opentelemetry_spec.rb <==
# Licensed to Elasticsearch B.V. under one or more contributor
# license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

if ENV['TEST_WITH_OTEL'] == 'true'
  ELASTICSEARCH_URL = ENV['TEST_ES_SERVER'] || "http://localhost:#{(ENV['PORT'] || 9200)}"
  raise URI::InvalidURIError unless ELASTICSEARCH_URL =~ /\A#{URI::DEFAULT_PARSER.make_regexp}\z/

  require 'spec_helper'

  context 'OpenTelemetry' do
    let(:exporter) { EXPORTER }
    before { exporter.reset }
    after { exporter.reset }
    let(:span) { exporter.finished_spans[0] }

    after do
      CLIENT.delete(index: 'myindex', id: 1); rescue
    end

    context 'when a request is instrumented' do
      it 'sets the span name to the endpoint id' do
        CLIENT.search(body: { query: { match: { a: 1 } } })
        expect(span.name).to eq 'search'
      end

      it 'sets the path parts' do
        CLIENT.index(index: 'myindex', id: 1, body: { title: 'Test' })
        expect(span.attributes['db.elasticsearch.path_parts.index']).to eq 'myindex'
        expect(span.attributes['db.elasticsearch.path_parts.id']).to eq 1
      end
    end
  end
end
